#!/bin/sh
#
# Package: auto-pilot
# Charles P. Wright <cwright@cs.sunysb.edu>
# Erez Zadok <ezk@cs.sunysb.edu>
# Copyright (c) 2001-2006 Stony Brook University

# Use common settings

source commonsettings || exit $?

if [ -z "$TESTDIR" ] ; then
	echo "You must specify the TESTDIR as an environment variable."
	exit 1
fi
if [ ! -d "$TESTDIR" ] ; then
	echo "TESTDIR ($TESTDIR) is not a directory."
	exit 1
fi

if [ "$APEPOCH" = 1 ] ; then
	for PROG in gcc g++ cc make gmake
	do
		if which $PROG >/dev/null 2>&1 ; then
			ap_log "["$PROG"version]"
			ap_logexec $PROG -v
			ap_log
		fi
	done
fi

if [ "$BENCH" = "gcc" ] ; then
	set_default PACKAGE gcc
elif [ "$BENCH" = "openssl" ] ; then
	set_default PACKAGE openssl
elif [ "$BENCH" = "amutils" ] ; then
	set_default PACKAGE am-utils
elif [ "$BENCH" = "linux" ] ; then
	set_default PACKAGE linux
elif [ "$PACKAGE" = "" ] ; then
	echo "Could not determine which benchmark to run." 1>&2
	exit 1
fi

if [ "$UNTAR" != "0" ]
then
	if ! [ -f "$PKGFILE" ] ; then
		if [ -z "$DATADIR" ] ; then
			echo "You must set DATADIR to location of the packages to run." 1>&2
			exit 1
		fi

		echo "Can not find $PKGFILE." 1>&2

		unset DIR
		unset PKGFILE
		unset ALT

		for x in ${DATADIR}/$PACKAGE*
		do
			if [ -f "$x" ] ; then
				if [ "$PKGFILE" = "" ] ; then
					PKGFILE=$x
					echo "Candidate for $BENCH: $PKGFILE"
				else
					echo "Alternate candidate for $BENCH: $x"
					ALT=1
				fi
			fi
		done
		if [ "$ALT" = "1" ] ; then
			echo "Multiple versions of $PACKAGE."
			exit 1
		fi
		if [ "$PKGFILE" = "" ] ; then
			echo "Could not find any version of $PACKAGE."
			exit 1
		fi
	fi	
fi
  
# Go into testdir

cd ${TESTDIR}

# Untar

if [ "$UNTAR" != "0" ]
then
	if [ `basename $PKGFILE` != `basename $PKGFILE .tar` ] ; then
		TAROPTS=-xf
	elif [ `basename $PKGFILE` != `basename $PKGFILE .tar.gz` ] ; then
		TAROPTS=-xzf
	elif [ `basename $PKGFILE` != `basename $PKGFILE .tar.bz2` ] ; then
		TAROPTS=-xjf
	fi
	ap_measure tar --no-same-owner $TAROPTS ${PKGFILE}
fi
	
# cd
if [ "$DIR" = "" ] ; then
	SAVEIGNORE=$GLOBIGNORE
	GLOBIGNORE=lost+found
	T=(*)
	GLOBIGNORE=$SAVEIGNORE
	if [ "${#T[@]}" = "1" -a "${T[0]}" != '*' ] ; then
		DIR=${T[0]}
		if [ ! -d "$DIR" ]
		then
			echo "Could not find directory for $PACKAGE." 1>&2
			echo "$DIR is not a directory!"	1>&2
			ls -l 1>&2
			exit 1
		fi
	else
		echo "Could not find directory for $PACKAGE." 1>&2
		if [ "${#T[@]}" -gt 1 ] ; then
			echo "Only one directory should exist after unpacking!" 1>&2
		fi
		echo "I searched in: " `pwd` 1>&2
		ls -l 1>&2
		exit 1
	fi
fi

cd $DIR

if [ -z "$COMPILE" -o "$COMPILE" != "0" ] ; then
	I=0
	if [ "$BENCH" = "gcc" ] ; then
		CMDLIST[$((I++))]=./configure
		CMDLIST[$((I++))]=make
	elif [ "$BENCH" = "openssl" ] ; then
		CMDLIST[$((I++))]=./configure
		CMDLIST[$((I++))]="make clean all"
	elif [ "$BENCH" = "amutils" ] ; then
		CMDLIST[$((I++))]=./buildall
	elif [ "$BENCH" = "linux" ] ; then
		MAJVERSION=`echo $PKGFILE | cut -d- -f2 | cut -d. -f 1`
		MINVERSION=`echo $PKGFILE | cut -d- -f2 | cut -d. -f 2`
		if [ "$MAJVERSION" -ge 2 -a "$MINVERSION" -ge 6 ] ; then
			CMDLIST[$((I++))]="make defconfig"
			CMDLIST[$((I++))]="make"
		else
			CMDLIST[$((I++))]="cp arch/"`uname -i`"/defconfig ./.config"
			CMDLIST[$((I++))]="make oldconfig"
			CMDLIST[$((I++))]="make dep"
			CMDLIST[$((I++))]="make vmlinux"
			CMDLIST[$((I++))]="make modules"
		fi
	elif [ ! -z "$COMPILECMD" ] ; then
		CMDLIST[$((I++))]="$COMPILECMD"
	else
		if ! ap_requirehook compilecommand $PACKAGE $PKGFILE
		then
			echo "Invalid option set for BENCH, no Compiliation command defined!" 1>&2
			exit 1
		fi
	fi
	unset I

	for ((I = 0; I < ${#CMDLIST[@]}; I++))
	do
		ap_measure ${CMDLIST[$I]}
	done
fi

# cd ..

cd ${TESTDIR}

# rm -rf

if [ -z "$DELETE" -o "$DELETE" != "0" ] ; then
	ap_measure rm -rf ${DIR}
	echo "Removal complete."
fi

echo "Compile script finished A-OK."

exit 0
